@@ -13,7 +13,8 @@ ee_sources <- function(foptions = list()) {
     data_sources <- GET(base_url, foptions)
     stop_for_status(data_sources)
     ds <- content(data_sources)
-    sources <- as.data.frame(do.call(rbind.data.frame, ds$results))
+    # sources <- rbind_all(ds$results)
+    sources <- ldply(ds$results, function(x) data.frame(x))
     sources$retrieved <- ymd_hms(sources$retrieved)
     sources
 }
